@@ -363,7 +363,11 @@ impl<T> RingBuffer<T> {
     #[inline]
     pub fn front_absolute_index(&self) -> Option<usize> {
         if self.len > 0 {
-            Some(self.tail + self.capacity)
+            if self.tail < self.head {
+                Some(self.tail + self.capacity)
+            } else {
+                Some(self.tail)
+            }
         } else {
             None
         }
